@@ -5,21 +5,22 @@ Created on 12 Sep 2020
 
 @author: semuadmin
 '''
+# pylint: disable=line-too-long
 
 TITLE = "PyGPSClient"
 WIKIURL = "https://en.wikipedia.org/wiki/NMEA_0183"
 GITHUBURL = "https://github.com/semuconsulting/PyGPSClient"
 
-COPYRIGHTTXT = "\u00A9 SEMU Consulting 2020\nBSD 2 Clause License. All Rights Reserved"
+COPYRIGHTTXT = "\u00A9 SEMU Consulting 2020\nBSD 3 License. All Rights Reserved"
 
 INTROTXT = "Welcome to PyGPSClient!"
 INTROTXTNOPORTS = "Welcome to PyGPSClient! Please connect a serial GPS device and restart."
 
 HELPTXT = "Help..About - display About dialog."
 
-ABOUTTXT = "PyGPSClient is a free, open-source NMEA & UBX GPS client application written" \
+ABOUTTXT = "PyGPSClient is a free, open-source NMEA & UBX GNSS/GPS client application written" \
     +" entirely in Python and tkinter.\n\n" \
-    +"Instructions and source code are available on Github at the link below."
+    +"Instructions and source code are available on GitHub at the link below."
 
 # Message text
 SETINITTXT = "Settings initialised"
@@ -36,10 +37,10 @@ NOWEBMAPERROR4 = "Check Internet connection."
 NOWEBMAPERROR5 = "No satellite fix."
 WEBMAPHTTPERROR = 'HTTP error downloading web map. Are you connected to the Internet?'
 WEBMAPERROR = 'Error downloading web map'
-SAVETITLE = "Select Save Directory"
-SELTITLE = "Select File for Import"
-WAITNMEADATA = "Waiting for NMEA data..."
-WAITUBXDATA = "Waiting for UBX data..."
+SAVETITLE = "Select Datalog Directory"
+READTITLE = "Select Datalog File"
+WAITNMEADATA = "Waiting for data..."
+WAITUBXDATA = "Waiting for data..."
 STOPDATA = "Serial reader process stopped"
 NOTCONN = "Not connected"
 UBXPOLL = "Polling current UBX configuration..."
@@ -77,12 +78,16 @@ BTNCAN = "Cancel"
 BTNRST = "Reset"
 
 # Label text
+LBLPROTDISP = "Protocols Displayed"
+LBLDATADISP = "Console Display"
 LBLUBXCONFIG = "UBX Configuration"
 LBLCTL = "Controls"
 LBLSET = "Settings"
 LBLCFGPRT = "CFG-PRT Port and Protocol Configuration"
 LBLCFGMSG = "CFG-MSG - UBX & NMEA Message Rate / Port Selection"
 LBLPRESET = "Preset UBX Configuration Commands"
+LBLDATALOG = "Enable Data Logging"
+LBLSTREAM = "Stream\nfrom file"
 
 # Dialog text
 DLGUBXCONFIG = "UBX Configuration"
@@ -92,3 +97,23 @@ DLGRESET = "Confirm Reset"
 DLGSAVE = "Confirm Save"
 DLGRESETCONFIRM = "Are you sure you want to reset the\ncurrent configuration to the\nfactory default in battery-backed RAM?"
 DLGSAVECONFIRM = "Are you sure you want to save\nthe current configuration to\nbattery-backed RAM?"
+
+# UBX Preset Command Descriptions
+PSTRESET = 'CFG-CFG - RESTORE FACTORY DEFAULTS'
+PSTSAVE = 'CFG-CFG - Save current configuration to RAM'
+PSTMINNMEAON = 'CFG-MSG - Turn ON minimum NMEA msgs'
+PSTALLNMEAON = 'CFG-MSG - Turn ON all NMEA msgs'
+PSTALLNMEAOFF = 'CFG-MSG - Turn OFF all NMEA msgs'
+PSTMINUBXON = 'CFG-MSG - Turn ON minimum UBX NAV msgs'
+PSTALLUBXON = 'CFG-MSG - Turn ON all UBX NAV msgs'
+PSTALLUBXOFF = 'CFG-MSG - Turn OFF all UBX NAV msgs'
+PSTALLINFON = 'CFG-INF - Turn ON all INF msgs'
+PSTALLINFOFF = 'CFG-INF - Turn OFF all non-error INF msgs'
+PSTALLLOGON = 'CFG-MSG - Turn ON all LOG msgs'
+PSTALLLOGOFF = 'CFG-MSG - Turn OFF all LOG msgs'
+PSTALLMONON = 'CFG-MSG - Turn ON all MON msgs'
+PSTALLMONOFF = 'CFG-MSG - Turn OFF all MON msgs'
+PSTALLRXMON = 'CFG-MSG - Turn ON all RXM msgs'
+PSTALLRXMOFF = 'CFG-MSG - Turn OFF all RXM msgs'
+PSTPOLLPORT = 'CFG-PRT - Poll Port config'
+PSTPOLLINFO = 'CFG-INF - Poll Info message config'
